nvector._core.n_EA_E_distance_and_azimuth2n_EB_E — nvector 0.7.5 documentation

# nvector._core.n_EA_E_distance_and_azimuth2n_EB_E

`n_EA_E_distance_and_azimuth2n_EB_E`(n_EA_E, distance_rad, azimuth, R_Ee=None)

  > Returns position B from azimuth and distance from position A

  Parameters
    n_EA_E: 3 x n array

      > n-vector(s) [no unit] of position A decomposed in E.

      distance_rad: n, array

        great circle distance [rad] from position A to B

      azimuth: n array

        Angle [rad] the line makes with a meridian, taken clockwise from north.

  Returns
    n_EB_E: 3 x n array

      n-vector(s) [no unit] of position B decomposed in E.